pypi
====

Format your package to upload on PyPi_::

    (dvlpt)$ pmg add pypi
    (dvlpt)$ pmg regenerate

Follow this simple tutorial: :doc:`pypi_tutorial`, to learn an easy way to register
your package on PyPi_.

Modifications
-------------

.. raw:: html
    :file: modifications.html


.. _PyPi: https://pypi.python.org/pypi

